@@ -1,5 +1,5 @@
 from numalogic.registry.artifact import ArtifactManager
-from numalogic.registry.mlflow import MLflowRegistrar
+from numalogic.registry.mlflow_registry import MLflowRegistrar
 
 
 __all__ = ["ArtifactManager", "MLflowRegistrar"]
